---
id: integrations
title: Integrations API
---

- `setup_fastapi(app, service_name=None, environment=None)`
- `setup_flask(app, service_name=None, environment=None)`
- `setup_django(environment=None, ...)`
